import path from 'path';

export default (config) => {
	config.module.rules.push({
		test: /\.(ts|tsx)$/,
		resourceQuery: /raw/,
		use: 'raw-loader',
		type: 'javascript/auto',
	});

	config.module.rules.push({
		test: /\.(ts|tsx)$/,
		use: {
			loader: 'ts-loader',
			options: {
				configFile: path.join(__dirname, './tsconfig.json'),
			},
		},
		exclude: /node_modules/,
		resourceQuery: { not: [/raw/] },
		include: [path.join(__dirname, '../packages'), path.join(__dirname, '../stories')],
	});

	config.devtool = 'inline-source-map';

	config.resolve.extensions.push('.ts', '.tsx', '.mdx', '.json', 'txt', 'css');

	config.resolve.alias = {
		...config.resolve.alias,
		config: path.join(__dirname, '../config'),
		'@prokyon/components': path.join(__dirname, '../packages/components/src'),
		'@prokyon/api': path.join(__dirname, '../packages/api/src'),
		'@prokyon/auth': path.join(__dirname, '../packages/auth/src'),
		'@prokyon/constants': path.join(__dirname, '../packages/constants/src'),
		'@prokyon/forms': path.join(__dirname, '../packages/forms/src'),
		'@prokyon/hooks': path.join(__dirname, '../packages/hooks/src'),
		'@prokyon/localization': path.join(__dirname, '../packages/localization/src'),
		'@prokyon/styles': path.join(__dirname, '../packages/styles/src'),
		'@prokyon/types': path.join(__dirname, '../packages/types/src'),
		'@prokyon/utils': path.join(__dirname, '../packages/utils/src'),
	};

	return config;
};
