import { createSlice, PayloadAction } from '@reduxjs/toolkit';

import { AUTH_REDUCER_NAME, AuthOption, AuthRootState, ModifyAuthOption } from './types';

const initialState: AuthOption = {
	authenticated: undefined,
	accessToken: undefined,
	refreshToken: undefined,
};

const authSlice = createSlice({
	name: AUTH_REDUCER_NAME,
	initialState,
	reducers: {
		setAuthAttribute: (state, action: PayloadAction<AuthOption>) => {
			return action.payload;
		},
		updateAuthAttribute: (state, action: PayloadAction<ModifyAuthOption>) => {
			state[action.payload.key] = action.payload.value;
		},
	},
});

export const setAuthAttribute = authSlice.actions.setAuthAttribute as <T>(
	attr: AuthOption<T>
) => PayloadAction<AuthOption<T>>;
export const updateAuthAttribute = authSlice.actions.updateAuthAttribute as <T>(
	attrs: ModifyAuthOption<T>
) => PayloadAction<ModifyAuthOption<T>>;

export const getAuthAttribute = (state: AuthRootState, name: keyof AuthOption) => state.prokyon.auth[name];

export default authSlice.reducer;
