import React, { ReactNode } from 'react';
import clsx from 'clsx';

import { StatusEnum } from '@prokyon/types/common';

export type ButtonProps = {
	blank?: boolean;
	className?: string;
	disabled?: boolean;
	label: string | ReactNode;
	onClick?: (e?: any) => void | Promise<void>;
	status?: StatusEnum;
	type?: 'submit' | 'reset' | 'button';
};

export const Button: React.FC<ButtonProps> = (props) => {
	const { disabled, onClick, status = StatusEnum.none, label, type = 'button', className, blank = false } = props;

	const handleOnClick = () => {
		if (onClick) {
			setTimeout(() => {
				onClick();
			}, 100);
		}
	};

	return (
		<button
			className={clsx(
				'button',
				{
					'button--blank': blank,
					'button--none': status === StatusEnum.none,
					'button--info': status === StatusEnum.info,
					'button--success': status === StatusEnum.success,
					'button--warning': status === StatusEnum.warning,
					'button--error': status === StatusEnum.error,
				},
				className
			)}
			onClick={handleOnClick}
			disabled={disabled}
			type={type}>
			{label}
		</button>
	);
};
