import React, { ReactNode } from 'react';
import clsx from 'clsx';

import { StatusEnum } from '@prokyon/types/common';

import CheckCircleIcon from './Icons/CheckCircle';
import ExclamationCircleIcon from './Icons/ExclamationCircle';
import ExclamationTriangleFillIcon from './Icons/ExclamationTriangle';
import HappyMessageIcon from './Icons/HappyMessage';
import InfoCircleIcon from './Icons/InfoCircle';

type IProps = {
	children?: ReactNode;
	status: StatusEnum;
	title?: string;
};

function Message(props: IProps) {
	const { status = StatusEnum.none, title, children } = props;
	return (
		<div
			className={clsx('message', {
				'message--none': status === StatusEnum.none,
				'message--info': status === StatusEnum.info,
				'message--success': status === StatusEnum.success,
				'message--warning': status === StatusEnum.warning,
				'message--error': status === StatusEnum.error,
			})}>
			<div className="text-3xl">
				<div>
					{status === StatusEnum.info && <InfoCircleIcon />}
					{status === StatusEnum.success && <CheckCircleIcon />}
					{status === StatusEnum.warning && <ExclamationTriangleFillIcon />}
					{status === StatusEnum.error && <ExclamationCircleIcon />}
					{status === StatusEnum.none && <HappyMessageIcon />}
				</div>
			</div>
			<div className="text-lg max-w-full flex-initial">
				<div>
					{title}
					<div className="text-sm">{children}</div>
				</div>
			</div>
		</div>
	);
}

export default Message;
