import React, { FC, ReactElement } from 'react';
import clsx from 'clsx';

import { DirectionEnum, SizeEnum } from '@prokyon/types/common';

export enum TitleSizeEnum {
	lg = 'lg',
	md = 'md',
	xl = 'xl',
}

export type TitleProps = {
	children?: ReactElement | string;
	className?: string;
	margin?: Partial<Record<DirectionEnum, number>>;
	size?: TitleSizeEnum;
};

export const Title: FC<TitleProps> = ({ size = SizeEnum.sm, children, className, margin }) => {
	const margins: string[] = [];
	for (const direct in margin) {
		margins.push(`m${direct}-${margin[direct]}`);
	}
	return (
		<div
			className={clsx(
				{
					'text-base': size === SizeEnum.sm,
					'text-2xl mb-1': size === SizeEnum.md,
					'text-3xl mb-2': size === SizeEnum.lg,
					'text-4xl mb-3': size === SizeEnum.xl,
				},
				margins,
				className
			)}>
			{children}
		</div>
	);
};
