import React, { FC, useEffect } from 'react';
import { useController, useFormContext } from 'react-hook-form';

import { Checkbox, CheckboxProps } from '@prokyon/components/Checkbox';
import { StatusEnum } from '@prokyon/types/common';
import { isNilOrEmpty } from '@prokyon/utils';

export type CheckboxFieldProps = CheckboxProps;

export const CheckboxField: FC<CheckboxFieldProps> = (props) => {
	const { name, checked, ...others } = props;

	const { control } = useFormContext();
	const {
		field,
		fieldState: { error },
	} = useController({ name, control });

	useEffect(() => {
		if (!isNilOrEmpty(checked)) {
			field.onChange(checked);
		}
	}, [checked]);

	return (
		<>
			<Checkbox
				{...others}
				name={name}
				checked={field.value}
				onChange={field.onChange}
				onBlur={field.onBlur}
				{...(error ? { status: StatusEnum.error } : {})}
			/>
			<div className="field-validationMessage">{error?.message}</div>
		</>
	);
};
