import React, { FC, useCallback, useEffect } from 'react';
import { is } from 'ramda';
import { useController, useFormContext } from 'react-hook-form';

import { RadioButton, RadioButtonProps } from '@prokyon/components/RadioButton';
import { StatusEnum } from '@prokyon/types/common';
import { Option } from '@prokyon/types/options';
import { isNilOrEmpty } from '@prokyon/utils';

export type RadioButtonFieldProps = RadioButtonProps;

export const RadioButtonField: FC<RadioButtonFieldProps> = (props) => {
	const { name, onClick, value, ...others } = props;

	const { control } = useFormContext();
	const {
		field,
		fieldState: { error },
	} = useController({ name, control });

	useEffect(() => {
		if (!isNilOrEmpty(value)) {
			field.onChange(value);
		}
	}, [value]);

	const handleClick = useCallback(
		(option: Option, e: React.MouseEvent<HTMLInputElement>): void => {
			field.onChange(option);
			if (is(Function, onClick)) {
				onClick(option, e);
			}
		},
		[onClick]
	);

	return (
		<>
			<RadioButton
				{...others}
				name={name}
				value={field.value}
				onClick={handleClick}
				{...(error ? { status: StatusEnum.error } : {})}
			/>
			<div className="field-validationMessage">{error?.message}</div>
		</>
	);
};
