import React, { FC, useCallback, useEffect } from 'react';
import { is } from 'ramda';
import { useController, useFormContext } from 'react-hook-form';

import { Selectbox, SelectBoxProps } from '@prokyon/components/Selectbox';
import { StatusEnum } from '@prokyon/types/common';
import { Option } from '@prokyon/types/options';
import { isNilOrEmpty } from '@prokyon/utils';

export type SelectBoxFieldProps = SelectBoxProps;

export const SelectBoxField: FC<SelectBoxFieldProps> = (props) => {
	const { name, onChange, value, ...others } = props;

	const { control } = useFormContext();
	const {
		field,
		fieldState: { error },
	} = useController({ name, control });

	useEffect(() => {
		if (!isNilOrEmpty(value)) {
			field.onChange(value);
		}
	}, [value]);

	const handleChange = useCallback(
		(option: Option, e: React.MouseEvent<HTMLInputElement>): void => {
			if (isNilOrEmpty(option)) {
				field.onChange(null);
				if (is(Function, onChange)) {
					onChange(undefined, e);
				}
			} else {
				field.onChange(option.code);
				if (is(Function, onChange)) {
					onChange(option, e);
				}
			}
		},
		[field]
	);

	return (
		<>
			<Selectbox
				{...others}
				name={field.name}
				value={field.value}
				onChange={handleChange}
				onBlur={field.onBlur}
				{...(error ? { status: StatusEnum.error } : {})}
			/>
			<div className="field-validationMessage">{error?.message}</div>
		</>
	);
};
