import React, { useEffect } from 'react';
import { useController, useFormContext } from 'react-hook-form';

import { TextField as TextFieldComponent, TextFieldProps } from '@prokyon/components/TextField';
import { StatusEnum } from '@prokyon/types/common';
import { isNilOrEmpty } from '@prokyon/utils';

export const TextField: React.FC<TextFieldProps> = ({ name, disabled, value, ...other }) => {
	const { control } = useFormContext();

	const {
		field,
		fieldState: { error },
	} = useController({ name, control });

	useEffect(() => {
		if (!isNilOrEmpty(value)) {
			field.onChange(value);
		}
	}, [value]);

	return (
		<div className="form-field-container">
			<TextFieldComponent
				{...other}
				name={name}
				value={field.value}
				onChange={field.onChange}
				onBlur={field.onBlur}
				disabled={disabled}
				{...(error ? { status: StatusEnum.error } : {})}
			/>
			<div className="field-validationMessage">{!disabled && error?.message}</div>
		</div>
	);
};
