import React, { FC, useEffect } from 'react';
import { omit } from 'ramda';
import { useController, useFormContext } from 'react-hook-form';

import { TimePicker, TimePickerProps } from '@prokyon/components/TimePicker/components/TimePicker';
import { StatusEnum } from '@prokyon/types/common';
import { isNilOrEmpty } from '@prokyon/utils';

export type TimePickerFieldProps = TimePickerProps<string>;

export const TimePickerField: FC<TimePickerFieldProps> = ({ name, value, ...others }) => {
	const { control } = useFormContext();
	const {
		field,
		fieldState: { error },
	} = useController({ name, control });

	useEffect(() => {
		if (!isNilOrEmpty(value)) {
			field.onChange(value);
		}
	}, [value]);

	return (
		<>
			<TimePicker
				{...(error ? { status: StatusEnum.error } : {})}
				{...omit(['onClick', 'onFocus'], others)}
				name={field.name}
				value={field.value}
				onChange={field.onChange}
				onBlur={field.onBlur}
			/>
			<div className="field-validationMessage">{error?.message}</div>
		</>
	);
};
