import React from 'react';
import { Meta, StoryObj } from '@storybook/react';

import { Modals } from '@prokyon/components/Modal';
import { AddModalButton } from '@prokyon/components/Modal/components/AddModalButton';
import { ModalWrapper } from '@prokyon/components/Modal/context';
import { TextField } from '@prokyon/components/TextField';

type Story = StoryObj<typeof AddModalButton>;

export default {
	component: AddModalButton,
	parameters: {
		docs: {
			description: {
				component:
					"`import { AddModalButton } from '@prokyon/components/Modal/components/AddModalButton';`",
			},
		},
	},
	tags: ['autodocs'],
	decorators: [
		(Story) => (
			<ModalWrapper>
				<Story />
				<Modals />
			</ModalWrapper>
		),
	],
} as Meta;

export const Default: Story = {
	name: 'Default',
	args: {
		id: 'default',
		title: 'Open modal 1',
		modalTitle: 'Default modal',
		Component: () => <div>Hi there</div>,
	},
};

export const Small: Story = {
	name: 'Small',
	args: {
		id: 'small',
		title: 'Open modal',
		modalTitle: 'Small modal',
		Component: () => (
			<div>
				<TextField name="search" label="Search" />
			</div>
		),
		style: {
			width: 250,
		},
	},
};

const ModalWindow = () => <div>Hi there, again</div>;

export const Multiple: Story = {
	name: 'Multiple',
	args: {
		id: 'multiple',
		title: 'Open modal',
		modalTitle: 'First modal',
		Component: () => (
			<div>
				Hello
				<AddModalButton
					Component={ModalWindow}
					title="Open next modal"
					modalTitle="Second modal"
					id="secondModal"
				/>
			</div>
		),
	},
};

export const WithCloseCallback: Story = {
	args: {
		id: 'withCloseCallback',
		title: 'Open modal',
		modalTitle: 'Modal',
		Component: () => <div>Hello</div>,
		props: {
			onClose: () => console.info('Close callback called.'),
		},
	},
};
