import React from 'react';
import type { Meta, StoryObj } from '@storybook/react';

import { Button } from '@prokyon/components/Button';
import RightFromBracketIcon from '@prokyon/components/Icons/RightFromBracket';
import { StatusEnum } from '@prokyon/types/common';

type Story = StoryObj<typeof Button>;

export default {
	component: Button,
	parameters: {
		docs: {
			description: {
				component: "`import { Button } from '@prokyon/components/Button';`",
			},
		},
	},
	tags: ['autodocs'],
} as Meta;

export const Default: Story = {
	args: {
		label: 'Click on ME!',
		status: StatusEnum.none,
	},
};

export const Success: Story = {
	args: {
		label: 'Click on ME!',
		status: StatusEnum.success,
	},
};

export const Info: Story = {
	args: {
		label: 'Click on ME!',
		status: StatusEnum.info,
	},
};

export const Warning: Story = {
	args: {
		label: 'Click on ME!',
		status: StatusEnum.warning,
	},
};

export const Error: Story = {
	args: {
		label: 'Click on ME!',
		status: StatusEnum.error,
	},
};
export const DefaultBlank: Story = {
	args: {
		label: 'Click on ME!',
		status: StatusEnum.none,
		blank: true,
	},
};

export const SuccessBlank: Story = {
	args: {
		label: 'Click on ME!',
		status: StatusEnum.success,
		blank: true,
	},
};

export const InfoBlank: Story = {
	args: {
		label: 'Click on ME!',
		status: StatusEnum.info,
		blank: true,
	},
};

export const WarningBlank: Story = {
	args: {
		label: 'Click on ME!',
		status: StatusEnum.warning,
		blank: true,
	},
};

export const ErrorBlank: Story = {
	args: {
		label: 'Click on ME!',
		status: StatusEnum.error,
		blank: true,
	},
};

export const LabelAsComponent: Story = {
	args: {
		label: <u>Click on ME!</u>,
		status: StatusEnum.none,
	},
};

export const LabelAsIcon: Story = {
	args: {
		label: <RightFromBracketIcon />,
		status: StatusEnum.none,
	},
};

export const Disabled: Story = {
	args: {
		label: 'Disabled',
		disabled: true,
		status: StatusEnum.none,
	},
};
