import React from 'react';
import { Meta, StoryObj } from '@storybook/react';
import clsx from 'clsx';

import { Grid, GridSizeEnum, GridVerticalAlignEnum } from '@prokyon/components/Grid';
import { GridCol } from '@prokyon/components/GridCol';

type Story = StoryObj<typeof Grid>;

const ColoredDiv = ({ children, className }: any) => {
	return <div className={clsx('bg-primary-300 text-primary-300', className)}>{children}</div>;
};

export default {
	component: Grid,
	tags: ['autodocs'],
	args: {
		children: <ColoredDiv>&nbsp;</ColoredDiv>,
	},
} as Meta<typeof Grid>;

const { sm, lg } = GridSizeEnum;

export const Default: Story = {
	render: () => (
		<Grid cols={{ [sm]: 12 }}>
			<GridCol colSpan={{ [sm]: 1 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 1 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 1 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 1 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 1 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 1 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 1 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 1 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 1 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 1 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 1 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 1 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 2 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 2 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 2 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 2 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 2 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 2 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 3 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 3 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 3 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 3 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 4 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 4 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 4 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 6 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 6 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
			<GridCol colSpan={{ [sm]: 12 }}>
				<ColoredDiv>&nbsp;</ColoredDiv>
			</GridCol>
		</Grid>
	),
};

export const Left: Story = {
	render: () => (
		<Grid cols={{ [sm]: 3 }}>
			<GridCol start={{ [sm]: 1 }} end={{ [sm]: 1 }}>
				<ColoredDiv>x</ColoredDiv>
			</GridCol>
		</Grid>
	),
};

export const Center: Story = {
	render: () => (
		<Grid cols={{ [sm]: 3 }}>
			<GridCol start={{ [sm]: 2 }} end={{ [sm]: 2 }}>
				<ColoredDiv>x</ColoredDiv>
			</GridCol>
		</Grid>
	),
};

export const Right: Story = {
	render: () => (
		<Grid cols={{ [sm]: 3 }}>
			<GridCol start={{ [sm]: 3 }} end={{ [sm]: 3 }}>
				<ColoredDiv>x</ColoredDiv>
			</GridCol>
		</Grid>
	),
};

export const Top: Story = {
	render: () => (
		<Grid cols={{ [sm]: 3 }}>
			<GridCol vertical={GridVerticalAlignEnum.top}>
				<ColoredDiv>x</ColoredDiv>
			</GridCol>
			<GridCol>
				<ColoredDiv>
					<br />x<br />
				</ColoredDiv>
			</GridCol>
			<GridCol vertical={GridVerticalAlignEnum.top}>
				<ColoredDiv>x</ColoredDiv>
			</GridCol>
		</Grid>
	),
};

export const Middle: Story = {
	render: () => (
		<Grid cols={{ [sm]: 3 }}>
			<GridCol vertical={GridVerticalAlignEnum.center}>
				<ColoredDiv>x</ColoredDiv>
			</GridCol>
			<GridCol>
				<ColoredDiv>
					<br />x<br />
				</ColoredDiv>
			</GridCol>
			<GridCol vertical={GridVerticalAlignEnum.center}>
				<ColoredDiv>x</ColoredDiv>
			</GridCol>
		</Grid>
	),
};

export const Bottom: Story = {
	render: () => (
		<Grid cols={{ [sm]: 3 }}>
			<GridCol vertical={GridVerticalAlignEnum.bottom}>
				<ColoredDiv>x</ColoredDiv>
			</GridCol>
			<GridCol>
				<ColoredDiv>
					<br />x<br />
				</ColoredDiv>
			</GridCol>
			<GridCol vertical={GridVerticalAlignEnum.bottom}>
				<ColoredDiv>x</ColoredDiv>
			</GridCol>
		</Grid>
	),
};

export const Responsive: Story = {
	render: () => (
		<Grid cols={{ [sm]: 1, [lg]: 3 }}>
			<GridCol>
				<ColoredDiv>x</ColoredDiv>
			</GridCol>
			<GridCol>
				<ColoredDiv>
					<br />x<br />
				</ColoredDiv>
			</GridCol>
			<GridCol>
				<ColoredDiv>x</ColoredDiv>
			</GridCol>
		</Grid>
	),
};
